[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] Miscellaneous tidying up, no semantic changes.



# HG changeset patch
# User emellor@xxxxxxxxxxxxxxxxxxxxxx
# Node ID 7c90df7df37e64704939bbfecc3b0b86a538d267
# Parent  b7790c2874c413b7b57804da7f689b706cfed9c0
Miscellaneous tidying up, no semantic changes.

Signed-off-by: Ewan Mellor <ewan@xxxxxxxxxxxxx>

diff -r b7790c2874c4 -r 7c90df7df37e tools/python/xen/xend/XendCheckpoint.py
--- a/tools/python/xen/xend/XendCheckpoint.py   Wed Nov 30 19:48:21 2005
+++ b/tools/python/xen/xend/XendCheckpoint.py   Wed Nov 30 19:48:54 2005
@@ -17,8 +17,6 @@
 import xen.util.auxbin
 
 import xen.lowlevel.xc
-
-from xen.xend.xenstore.xsutil import IntroduceDomain
 
 from XendError import XendError
 from XendLogging import log
diff -r b7790c2874c4 -r 7c90df7df37e tools/python/xen/xend/XendProtocol.py
--- a/tools/python/xen/xend/XendProtocol.py     Wed Nov 30 19:48:21 2005
+++ b/tools/python/xen/xend/XendProtocol.py     Wed Nov 30 19:48:54 2005
@@ -100,7 +100,7 @@
         """
         return self.xendRequest(url, "POST", args)
 
-    def handleStatus(self, version, status, message):
+    def handleStatus(self, _, status, message):
         """Handle the status returned from the request.
         """
         status = int(status)
@@ -114,8 +114,8 @@
         """Handle the data returned in response to the request.
         """
         if data is None: return None
-        type = self.getHeader('Content-Type')
-        if type != sxp.mime_type:
+        typ = self.getHeader('Content-Type')
+        if typ != sxp.mime_type:
             return data
         try:
             pin = sxp.Parser()
@@ -205,5 +205,5 @@
             path = xroot.get_xend_unix_path()
         self.path = path
 
-    def makeConnection(self, url):
+    def makeConnection(self, _):
         return UnixConnection(self.path)
diff -r b7790c2874c4 -r 7c90df7df37e tools/python/xen/xend/XendRoot.py
--- a/tools/python/xen/xend/XendRoot.py Wed Nov 30 19:48:21 2005
+++ b/tools/python/xen/xend/XendRoot.py Wed Nov 30 19:48:54 2005
@@ -171,7 +171,7 @@
         v = self.get_config_value(name, val)
         try:
             return int(v)
-        except Exception, ex:
+        except Exception:
             raise XendError("invalid xend config %s: expected int: %s" % 
(name, v))
 
     def get_xend_http_server(self):
diff -r b7790c2874c4 -r 7c90df7df37e tools/python/xen/xend/server/netif.py
--- a/tools/python/xen/xend/server/netif.py     Wed Nov 30 19:48:21 2005
+++ b/tools/python/xen/xend/server/netif.py     Wed Nov 30 19:48:54 2005
@@ -71,8 +71,8 @@
         script = os.path.join(xroot.network_script_dir,
                               sxp.child_value(config, 'script',
                                               xroot.get_vif_script()))
-        type = sxp.child_value(config, 'type')
-        if type == 'ioemu':
+        typ = sxp.child_value(config, 'type')
+        if typ == 'ioemu':
             return (None,{},{})
         bridge = sxp.child_value(config, 'bridge')
         mac    = sxp.child_value(config, 'mac')
diff -r b7790c2874c4 -r 7c90df7df37e tools/python/xen/xend/server/relocate.py
--- a/tools/python/xen/xend/server/relocate.py  Wed Nov 30 19:48:21 2005
+++ b/tools/python/xen/xend/server/relocate.py  Wed Nov 30 19:48:54 2005
@@ -16,7 +16,6 @@
 # Copyright (C) 2005 XenSource Ltd
 #============================================================================
 
-import socket
 import sys
 import StringIO
 
diff -r b7790c2874c4 -r 7c90df7df37e tools/python/xen/xend/tests/test_sxp.py
--- a/tools/python/xen/xend/tests/test_sxp.py   Wed Nov 30 19:48:21 2005
+++ b/tools/python/xen/xend/tests/test_sxp.py   Wed Nov 30 19:48:54 2005
@@ -6,8 +6,8 @@
 class test_sxp(unittest.TestCase):
 
     def testAllFromString(self):
-        def t(input, expected):
-            self.assertEqual(xen.xend.sxp.all_from_string(input), expected)
+        def t(inp, expected):
+            self.assertEqual(xen.xend.sxp.all_from_string(inp), expected)
 
         t('String',           ['String'])
         t('(String Thing)',   [['String', 'Thing']])
diff -r b7790c2874c4 -r 7c90df7df37e tools/python/xen/xend/uuid.py
--- a/tools/python/xen/xend/uuid.py     Wed Nov 30 19:48:21 2005
+++ b/tools/python/xen/xend/uuid.py     Wed Nov 30 19:48:54 2005
@@ -25,14 +25,14 @@
 import random
 
 
-def getUuidUuidgen(random = True):
+def getUuidUuidgen(randomly = True):
     """Generate a UUID using the command uuidgen.
 
     If random is true (default) generates a random uuid.
     If random is false generates a time-based uuid.
     """
     cmd = "uuidgen"
-    if random:
+    if randomly:
         cmd += " -r"
     else:
         cmd += " -t"
@@ -42,7 +42,7 @@
 def getUuidRandom():
     """Generate a random UUID."""
     
-    return [ random.randint(0, 255) for i in range(0, 16) ]
+    return [ random.randint(0, 255) for _ in range(0, 16) ]
 
 
 #uuidFactory = getUuidUuidgen
@@ -25,14 +25,14 @@
     """Generate a UUID using the command uuidgen.
 
-    If random is true (default) generates a random uuid.
-    If random is false generates a time-based uuid.
+    If randomly is true (default) generates a random uuid.
+    If randomly is false generates a time-based uuid.
     """
     cmd = "uuidgen"

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.